==> maxdb-7.5.00_7.5.00.34.orig.tar.gz: maxdb-7.5.00-7.5.00.34.orig/MaxDB_ORG/sys/src/eo/heo11_1.h <==
/*!
  @file           heo11_1.h
  @author         JoergM
  @special area   xparam
  @brief          description ...
  @see            example.html ...

\if EMIT_LICENCE

    ========== licence begin  GPL
    Copyright (c) 2000-2005 SAP AG

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
    ========== licence end



\endif
*/



#ifndef HEO11_1_H
#define HEO11_1_H

/*===========================================================================*
 *  INCLUDES                                                                 *
 *===========================================================================*/

/*===========================================================================*
 *  FUNCTION PROTOTYPES ( RTE internal only )                                *
 *===========================================================================*/

externC void    sql11c_SeqBinReadXParam  (  tsp00_Int4         XParamFileID,
                                            char               *Buf ,
                                            tsp00_Int4          i4BytesToRead ,
                                            tsp00_Int4         *pi4BytesRead,
                                            tsp00_ErrText         acErrorText,
                                            tsp00_XpReturnCode *pucXParamReturnCode );

externC void    sql11c_SeqBinWriteXParam (  tsp00_Int4         XParamFileID,
                                            char              *Buf ,
                                            tsp00_Int4         i4BytesToWrite ,
                                            tsp00_Int4        *pi4BytesWritten,
                                            tsp00_ErrText         acErrorText,
                                            tsp00_XpReturnCode *pucXParamReturnCode );

externC void    sql11c_ResetParamChangedFlag ( tsp00_Int4       XParamFileID,
                                               tsp00_ErrText      acErrorText,
                                               tsp00_BoolAddr   pbOk );

#endif  /* HEO11_1_H */

==> maxdb-7.5.00_7.5.00.44.orig.tar.gz: maxdb-7.5.00-7.5.00.44.orig/MaxDB_ORG/sys/src/eo/heo12_1.h <==
/*!
  @file           heo12_1.h
  @author         JoergM
  @special area   GetDefaultDBName ( using sqlarg3 )
  @brief          description ...
  @see            example.html ...

\if EMIT_LICENCE

    ========== licence begin  GPL
    Copyright (c) 2000-2005 SAP AG

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
    ========== licence end



\endif
*/



#ifndef HEO12_1_H
#define HEO12_1_H

/*===========================================================================*
 *  INCLUDES                                                                 *
 *===========================================================================*/

#include "gsp00.h"

/*===========================================================================*
 *  FUNCTION PROTOTYPES                                                      *
 *===========================================================================*/

externC int GetDefaultDBName ( tsp00_DbNamec  DefaultDBName, 
		                       tsp00_ErrTextc ErrTextc ) ;

#endif  /* HEO95_H */
